# funcgui

##### this is a functions aggregate

## Installation

```shell
pip install funcgui
```



```python
import funcgui

# createPyGui
funcgui.createPyGui(name=)

# create
funcgui.create(name=)

# echo
funcgui.echo(name=, value=)

# createPy
funcgui.createPy(name=, value=)
```
